@@ -1,20 +1,12 @@
 import click
 
-from .core import prefetch_github
-from .effect import perform_effects
+from .public import nix_prefetch_github
 from .version import VERSION_STRING
 
-
-def nix_prefetch_github(owner, repo, prefetch=True, rev=None, fetch_submodules=False):
-    return perform_effects(
-        prefetch_github(
-            owner=owner,
-            repo=repo,
-            rev=rev,
-            prefetch=prefetch,
-            fetch_submodules=fetch_submodules,
-        )
-    )
+PREFETCH_DEFAULT = True
+NIX_DEFAULT = False
+FETCH_SUBMODULES_DEFAULT = True
+REV_DEFAULT = None
 
 
 @click.command("nix-prefetch-github")
@@ -22,18 +14,31 @@ def nix_prefetch_github(owner, repo, prefetch=True, rev=None, fetch_submodules=F
 @click.argument("repo")
 @click.option(
     "--prefetch/--no-prefetch",
-    default=True,
+    default=PREFETCH_DEFAULT,
     help="Prefetch given repository into nix store",
 )
-@click.option("--nix", is_flag=True, help="Format output as Nix expression")
 @click.option(
-    "--fetch-submodules",
+    "--nix/--json",
     is_flag=True,
+    help="Format output as Nix expression",
+    default=NIX_DEFAULT,
+)
+@click.option(
+    "--fetch-submodules/--no-fetch-submodules",
+    is_flag=True,
+    default=FETCH_SUBMODULES_DEFAULT,
     help="Whether to fetch submodules contained in the target repository",
 )
-@click.option("--rev", default=None, type=str)
+@click.option("--rev", default=REV_DEFAULT, type=str)
 @click.version_option(version=VERSION_STRING, prog_name="nix-prefetch-github")
-def _main(owner, repo, prefetch, nix, rev, fetch_submodules):
+def main(
+    owner,
+    repo,
+    prefetch=PREFETCH_DEFAULT,
+    nix=NIX_DEFAULT,
+    rev=REV_DEFAULT,
+    fetch_submodules=FETCH_SUBMODULES_DEFAULT,
+):
     prefetched_repository = nix_prefetch_github(
         owner, repo, prefetch, rev, fetch_submodules=fetch_submodules
     )
