@@ -7,8 +7,7 @@ from attr import attrib, attrs
 
 @attrs
 class GetListRemote:
-    owner = attrib()
-    repo = attrib()
+    repository = attrib()
 
 
 @attrs
@@ -23,19 +22,17 @@ class ShowWarning:
 
 @attrs
 class TryPrefetch:
-    owner = attrib()
-    repo = attrib()
+    repository = attrib()
     sha256 = attrib()
     rev = attrib()
-    fetch_submodules = attrib(default=False)
+    fetch_submodules = attrib()
 
 
 @attrs
 class CalculateSha256Sum:
-    owner = attrib()
-    repo = attrib()
+    repository = attrib()
     revision = attrib()
-    fetch_submodules = attrib(default=False)
+    fetch_submodules = attrib()
 
 
 @attrs
@@ -56,3 +53,8 @@ class DetectRevision:
 @attrs
 class AbortWithErrorMessage:
     message = attrib()
+
+
+@attrs
+class GetRevisionForLatestRelease:
+    repository = attrib()
